import { defineComponent, toRefs, ref, PropType } from 'vue';
import styles from './pen.module.less';
import { ToolType } from '../../index';
import exit1 from '../../image/exit1.png';
import exit2 from '../../image/exit2.png';

export default defineComponent({
  name: 'pen-page',
  props: {
    show: {
      type: Boolean,
      default: false
    },
    type: {
      type: String as PropType<ToolType>,
      default: 'pen'
    },
    close: {
      type: Function,
      default: () => ({})
    }
  },
  setup(props) {
    const { show, type } = toRefs(props);
    const firstRender = ref(true);
    const origin = /(localhost|192)/.test(location.host)
      ? 'https://test.lexiaoya.cn/'
      : location.origin;
    const src = `${origin}/classroom-whiteboard?type=${props.type}`;

    return () => (
      <div
        class={[
          styles.pen,
          type.value === 'whiteboard' ? styles.whiteboard : '',
          firstRender.value ? styles.dely : '',
          show.value ? styles.open : styles.hide
        ]}>
        <iframe
          class={styles.iframe}
          frameborder="0"
          width="100vw"
          height="100vh"
          src={src}
          onLoad={() => {
            firstRender.value = false;
          }}></iframe>
        <div class={styles.rightItem} onClick={() => props.close()}>
          <img src={props.type === 'pen' ? exit2 : exit1} />
        </div>
      </div>
    );
  }
});
